check_normal_prior: Checks for validity of values for use as normal distribution...

View source: R/check_normal_prior.R

check_normal_priorR Documentation

Checks for validity of values for use as normal distribution parameters.

Description

Should a pair of numeric values, second value should be non-zero. Stops execution with an error.

Usage

check_normal_prior(values, parameter)

Arguments

values

Parameters for normal distribution.

parameter

Name of the parameter for which the prior is defined.

Value

Logical TRUE, if none of the tests fail

Examples

check_normal_prior(c(0, 1), "tau")

bistablehistory documentation built on March 3, 2026, 5:06 p.m.